<?php
/*
    LWAT, LDAP Webbased Administration Tool
    Copyright (C) 2007  Finn-Arne Johansen <faj@bzz.no>, BzzWare AS, Norway

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

require_once ("/etc/lwat/config.php"); 
session_start () ; 

require_once ("functions.php"); 

loadLocale () ;
ob_start () ; 


header('Content-type: text/html; charset=UTF-8');

function userDelGroup ($ldap, $uid, $gid) {
    global $groupbase ; 
    $filter="(&(objectClass=posixGroup)(gidNumber=" . $gid . "))";
    $want = array (); 
    $searchbase=$groupbase ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $change = array (); 
    $change["memberUid"][] = $uid ; 
    @ldap_mod_del($ldap, $entries[0]["dn"], $change) ;
}

function userAddGroup ($ldap, $uid, $gid) {
    global $groupbase ; 
    $filter="(&(objectClass=posixGroup)(gidNumber=" . $gid . "))";
    $want = array (); 
    $searchbase=$groupbase ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $change = array (); 
    $change["memberUid"][] = $uid ; 
    @ldap_mod_add($ldap, $entries[0]["dn"], $change) ;
}

function changeGroup ($ldap, $gid, $cn, $description) {
    global $groupbase ; 
    $filter="(&(objectClass=posixGroup)(gidNumber=" . $gid . "))";
    $want = array (); 
    $searchbase=$groupbase ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $change = array (); 
    $change["description"][] = $description ; 
    ldap_modify($ldap, $entries[0]["dn"], $change) ;
    showGroup ($ldap, $gid);
}

function addGroup ($ldap, $cn, $description) {
    global $useLisGroup, $groupbase, $base ; 
    $filter="(|(uid=" . $cn . ")(cn=" . $cn . "))";
    $want = array ("cn","uid"); 
    $searchbase=$base ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    if ($entries["count"] > 0)  {
        echo _("Sorry, there is a lready a group/user with name ") . $cn . "<BR>" ;
        $gidNumber = $entries[0]["gidNumber"][0] ;
    } else {  
	$gidNumber = getnextid ($ldap, $base) ;
	$add = array (); 
	if ($useLisGroup) {
	    $add["objectClass"] = array ("top", "posixGroup", "lisGroup") ; 
	    $add["groupType"] = "school_class" ; 
	} else
	    $add["objectClass"] = array ("top", "posixGroup") ; 
	$add["cn"] = $cn ; 
	$add["gidNumber"] = $gidNumber ;
	$add["description"] = $description ; 
	ldap_add($ldap, "cn=" . $cn . "," . $groupbase, $add) ;
    }
    showGroup ($ldap, $gidNumber);
}

function sambaAddInfo ($ldap, $userldif, $userpw) {
    $sambaldif = array ()  ;
    $sambahash = ntlmgen ($userpw) ;
    $sambaldif['sambaSID'] = get_sambasid ($ldap, $userldif['uidNumber']) ;
    $sambaldif["sambaAcctFlags"] = "[U          ]" ;
    $sambaldif["sambaLMPassword"] = substr ($sambahash, 0,32) ;
    $sambaldif["sambaNTPassword"] = substr ($sambahash, 32) ;
    return $sambaldif ;
}

function addUser ($ldap, $cn, $template, $username) {
    global $groupbase, $base, $domain, $useLisGroup ; 
    $templates = parse_ini_file ('/etc/lwat/admin.ini', true) ; 
    $template = $templates[$template] ;
    $userpw = pwgen () ;
    $sn = get_sn ($username) ;
    $userid = getnextid ($ldap, $base) ;
    $userldif['uidNumber'] = $userid ;
    $userldif['gidNumber'] = $userid ;
    $userldif['uid'] = $username ;
    $userldif['cn'] = $cn ;
    $userldif['sn'] = $sn ;
    $userldif['userPassword'] = cryptgen($userpw) ;
    if ($useLisGroup) {
	$groupldif["objectClass"] = array ("top", "posixGroup", 'lisGroup') ; 
	$groupldif["groupType"] = "personal" ;
    } else
	$groupldif["objectClass"] = array ("top", "posixGroup") ; 
    $groupldif["cn"] = $username ; 
    $groupldif["gidNumber"] = $userid ;
    $groupldif["description"] = "$cn personal group" ;
    $replace=array("%username%", "%base%", "%domain%") ;
    $replacewith =array($username, $base, $domain) ;
    foreach ($template as $key => $value) {
        $value = str_replace ($replace, $replacewith, $value) ;
        switch ($key) {
             case "ou":
                 $ou=$value ;
                 break ;
             case "groups":
                 $groups= explode (" ", $value) ;
                 break ;
             case "objectClass":
                 $userldif['objectClass'] = explode (" ", $value); 
                 break ;
             default:
                 $userldif[$key] = $value ;
                 break ;
        }
    }
    if (in_array ('sambaSamAccount',$userldif['objectClass'])) 
        $userldif = (array_merge($userldif, sambaAddInfo ($ldap, $userldif, $userpw))) ;
    if (!ldap_add($ldap, "uid=" . $username . "," . $ou, $userldif)) {
        debug (array_merge(array ('dn' => "uid=" . $username . "," . $ou), $userldif)) ;
        return ; 
    }
    if ($useLisGroup) $ou=$groupbase ;
    if (!ldap_add($ldap, "cn=" . $username . "," . $ou, $groupldif)) {
        debug (array('dn' => "cn=" . $username . "," . $ou, 'groupldif' => $groupldif)) ;
        return ;
    }
    foreach ($groups as $group) {
        $filter="(&(objectClass=posixGroup)(cn=" . $group . "))";
        $want = array ('gidNumber'); 
        $result = ldap_search($ldap, $groupbase, $filter, $want);
        $entries = ldap_get_entries ($ldap, $result);
        $gid= $entries[0]['gidnumber'][0] ;
        userAddGroup ($ldap, $username, $gid) ;
    }
    printf(_("Added user %s with username %s and password %s"), $cn, $username, $userpw);
    userAddForm (true) ;
}

function changeUser ($ldap, $uid, $cn) {
    global $base ; 
    $filter="(&(objectClass=posixAccount)(uid=" . $uid . "))";
    $want = array (); 
    $result = ldap_search($ldap, $base, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $change = array (); 
    $change["cn"][] = $cn ; 
    if (!ldap_modify($ldap, $entries[0]["dn"], $change))
        debug (array ('dn' => $entries[0]["dn"], 'change' => $change)) ;
    showUser ($ldap, true, $uid); 
}

function showGroup ($ldap, $gid) {
    global $base, $groupbase ; 
    $filter="(&(objectClass=posixGroup)(gidNumber=" . $gid . "))";
    $want = array ("memberUid", "member", "description", "cn") ;
    $searchbase=$groupbase ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $authentication= ( $entries[0]["member"]["count"] > 0 ); 
    $description=$entries[0]["description"][0]; 
    $cn=$entries[0]["cn"][0]; 
    $memberUid=$entries[0]["memberuid"];
    ?>
<form method="post" name="group">
    <table>
        <TR>
            <TD><?php echo _("Group name:"); ?></TH>
            <TD>
		<input type=text name="cn" 
		       value="<?php echo $cn; ?>" >
            </TD>
            <TD><?php echo _("Group id:"); ?></TH>
            <TD>
		<input type=text name="gid" 
		       value="<?php echo $gid; ?>" 
		       readonly >
            </TD>
        </TR>
        <TR>
            <TD><?php echo _("Description:"); ?></TH>
            <TD colspan=3>
                <input type=text name=description size=50 
                       value="<?php echo $description; ?>" >
            </TD>
        </TR>
        <TR>
            <TD></TD>
            <TD>
                <?php echo _("Authentication group"); ?>
                <input type=checkbox name="Authenticate" 
                <?php if ($authentication) echo "checked" ; ?>
                />
            </TD>
            <TD>
                <input type=button name=save value=Save
<?php
    echo 'onClick="Action(\'changeGroup&gid=' ;
    echo $gid; 
    echo '&cn=\' + cn.value' ;
    echo '+ \'&description=\' + description.value' ;
    echo ', \'main\')">' ;
?>
	    </TD>
            <TD><input type=reset name=reset value=Reset></TD>
        </TR>
    </TABLE>
</form>
<div id=sub>
<H3><?php echo _("Members:"); ?></H3>
    <?php
    $filter="" ; 
    for ($i=0 ; $i < $memberUid["count"] ; $i++) {
        $filter .= "(uid=" . $memberUid[$i] . ")" ; 
    }
    $filter="(&(objectClass=posixAccount)(|" . $filter . "))" ; 
    $want = array ("uid", "cn") ;
    $searchbase=$base ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    for ($i=0 ; $i < $entries["count"] ; $i++) {
	echo '<A href="javascript:;" ';
	echo 'onclick="Action (\'showUser&text=' . 
				$entries[$i]["uid"][0] . '\',\'main\')";>' ;
	echo $entries[$i]["cn"][0] . '</A><BR>' ;
    }
}

function showUser ($ldap, $authenticated, $uid) {
    global $base, $groupbase ; 
    $filter="(&(objectClass=posixAccount)(uid=" . $uid . "))";
    $want = array ("uidNumber", "uid", "cn", "gidNumber") ;
    $searchbase=$base ; 
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $count=$entries["count"] ;
    if ($count) {
        $cn=$entries[0]["cn"][0]; 
        $uidNumber=$entries[0]["uidnumber"][0];
        $gidNumber=$entries[0]["gidnumber"][0];
	$filter="(&(objectClass=posixGroup)(gidNumber=" . $gidNumber . ")(!(cn=nextID))(!(cn=lastID)))";
	$want = array ("cn", "gidNumber") ;
	$searchbase=$base ; 
        $result = ldap_search($ldap, $searchbase, $filter, $want);
	$entries = ldap_get_entries ($ldap, $result);
        $userGroup=$entries[0]["cn"][0]; 
        ?>
<form method="post" name="user">
    <table>
        <TR>
            <TD><?php echo _("Username:"); ?></TH>
            <TD>
		<input type=text name="uid" 
		       value="<?php echo $uid; ?>" 
		       readonly>
            </TD>
            <TD><?php echo _("Userid:") ; ?></TH>
            <TD>
		<input type=text name="uidNumber" 
		       value="<?php echo $uidNumber; ?>" 
		       readonly>
            </TD>
        </TR>
        <TR>
            <TD><?php ("Full name:"); ?></TH>
            <TD colspan=3>
                <input type=text name=cn size=50 
                       value="<?php echo $cn; ?>" >
            </TD>
        </TR>
        <TR>
            <TD><?php echo _("Group id:") ; ?></TH>
            <TD>
                 <input type=text name=gidNumber readonly
                        value="<?php echo $userGroup; ?>" >
            </TD>
            <TD colspan=2>
                <input type=button name=save value=Save 
<?php
    echo 'onClick="Action(\'changeUser&uid=' ;
    echo $uid; 
    echo '&cn=\' + cn.value' ;
    echo ', \'main\');">' ; 
?>
            <input type=reset name=reset value=Reset>
                <input type=button name=newpw value="New password"
<?php
    echo 'onClick="Action(\'newPassAsk&uid=' . $uid . '\', \'sub\')">'; 
?>
            </TD>
        </TR>
    </TABLE>
    <H3><?php echo _("Groups:"); ?></H3>
    <div id=sub>
<?php
    showUserGroups($ldap, $authenticated, $uid)
?>
</form>
        <?php
    } else {
        echo _("No matching objects") ."<BR>" ;
    }
}

function showUserGroups ($ldap, $authenticated ,$uid) {
    global $useLisGroup, $groupbase ;
?>
    <table>
        <tr>
            <th><?php echo _("Member of"); ?></th>
            <th> </th>
            <th><?php echo _("Not member of"); ?></th>
        </tr>
        <tr>
            <td>
                <select name=member size=10>
		    <?php
	if ($useLisGroup) 
	    $filter="(&(objectClass=posixGroup)(!(groupType=personal))(memberUid=" . $uid . "))";
	else
	    $filter="(&(objectClass=posixGroup)(memberUid=" . $uid . "))";
	$want = array ("cn", "gidNumber") ;
	$searchbase=$groupbase ; 
        $result = ldap_search($ldap, $searchbase, $filter, $want);
	$entries = ldap_get_entries ($ldap, $result);
        for ($i=0 ; $i < $entries["count"] ; $i++) {
            echo "<option value=" . $entries[$i]["gidnumber"][0] . ">" ;
            echo $entries[$i]["cn"][0] . "</option>" ;
        }
		    ?>
                </select>
            </td>
            <td>
<?php
    if ($authenticated) {
        $target='\'sub\'' ;
        $action ='\'userDelGroup&uid=' . $uid ; 
        $action .= '&gid=\' + member.value' ;
    } else {
        $target = '\'main\'' ; 
        $action = '\'loginForm\'' ; 
    }
?>
                <input type=button name=Remove value=&gt;
                       onClick="Action(<?php echo $action . "," . $target ?>)">
                <br>
<?php
    if ($authenticated) {
        $target='\'sub\'' ;
        $action ='\'userAddGroup&uid=' . $uid ; 
        $action .= '&gid=\' + nonmember.value';
    } else {
        $target = '\'main\'' ; 
        $action = '\'loginForm\'' ; 
    }
?>
                <input type=button name=Add value=&lt; 
                       onClick="Action(<?php echo $action . "," . $target ?>)">
            </td>
            <td>
                <select name=nonmember size=10>
		    <?php
	if ($useLisGroup) 
	    $filter="(&(objectClass=posixGroup)(!(groupType=personal))(!(memberUid=" . $uid . ")))";
	else
	    $filter="(&(objectClass=posixGroup)(!(memberUid=" . $uid . ")))";
	$want = array ("cn", "gidNumber") ;
	$searchbase=$groupbase ; 
        $result = ldap_search($ldap, $searchbase, $filter, $want);
	$entries = ldap_get_entries ($ldap, $result);
        for ($i=0 ; $i < $entries["count"] ; $i++) {
            echo "<option value=" . $entries[$i]["gidnumber"][0] . ">" ;
            echo $entries[$i]["cn"][0] . "</option>" ;
        }
		    ?>
                </select>
            </td>
        <tr>
    <table>
<?php
}


function showResult ($ldap, $type, $text) {
    global $useLisGroup, $base, $groupbase ; 

    if ($text == "*") $text="" ; 
    switch ($type) {
        case "User":
            $filter="(&(objectClass=posixAccount)(|(cn=" . $text . "*)(uid=" . $text . ")))";
	    $want = array ("uidNumber", "uid", "cn") ;
	    $searchbase=$base ; 
	    $action="showUser" ; 
	    $show="uid" ; 
            break ;
        case "Group":
            if ($useLisGroup)
                $filter="(&(objectClass=posixGroup)(!(groupType=personal))(cn=" . $text . "*))" ;
            else 
                $filter="(&(objectClass=posixGroup)(cn=" . $text . "*))" ;
	    $want = array ("gidNumber", "cn") ;
	    $searchbase=$groupbase ; 
	    $action="showGroup" ; 
	    $show="gidnumber" ; 
            break ;
        default:
           return ;
    }
    $result = ldap_search($ldap, $searchbase, $filter, $want);
    $entries = ldap_get_entries ($ldap, $result);
    $count=$entries["count"] ;
    if ($count) {
	for ($i=0 ; $i < $count ; $i++) {
	    echo '<A href="javascript:;" ';
	    echo 'onclick="Action (\'' . $action . '&text=' . 
	                            $entries[$i][$show][0] . '\',\'main\')";>' ;
	    echo $entries[$i]["cn"][0] . '</A><BR>' ;
	}
    } else {
        echo _("No matching objects") . "<BR>" ;
    }
}

function userAddForm ($authenticated) {
        $templates = parse_ini_file ("/etc/lwat/admin.ini", true); 
        ?>
<form method="post" name="add">
    <table>
    <tr>
    <td colspan=2>
    <?php echo _("Enter full name of the user:"); ?>
    </td>
    </tr>
    <tr>
    <td colspan=2>
    <input type=text name="cn" size=50 
           onkeyup="Action('getUsername&cn=' + cn.value, 'newusername');" >
    </td>
    </tr>
    <tr>
    <td>
    <?php echo _("Select user template:") ; ?>
    </td>
    <td>
    <?php echo _("Username:") ; ?>
    </td>
    </tr>
    <tr>
    <td>
    <select name=template>
<?php
    foreach ($templates as $key => $value) {
	echo '<option value="' . $key . '">' . $key . '</option>\n'; 
    }
?>
    </select><BR>
    </td>
    <td>
    <div id=newusername>
    <input type=text name=username maxlength=8>
    </div>
    </td>
    </tr>
    <tr>
    <td colspan=2>
    <?php
    if ($authenticated) {
        $action ='\'addUser&cn=\' + cn.value '; 
        $action .= ' + \'&username=\' + username.value' ;
        $action .= ' + \'&template=\' + template.value' ;
    } else {
        $action = '\'loginForm\'' ; 
    }
    ?>
    <input type=button name=Remove value=Save
            onClick="Action(<?php echo $action ?>,'main')">
    &nbsp;
    <input type=reset name=reset value=Reset> 
    </td>
    </tr>
</form>
        <?php
}

$ldap=ldap_connect ($ldaphost); 
$authenticated = ($_COOKIE['Authenticated'] == "True") ;
$key = $_SESSION['key'] ;
if ($key == "") {
    $key = crypt(sprintf (gettimeofday (true))) ;
    $_SESSION['key'] = $key ; 
    if ($authenticated) {
        setcookie ("Authenticated", "False") ;
    }
    $authenticated = false ; 
} 
ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
@ldap_start_tls($ldap) ; 
if ($authenticated) {
    $admindn = $_COOKIE['admindn'] ; 
    $adminpw = xorstring ($key, $_COOKIE['xorstring']) ; 
    $authenticated = ($adminpw <> "") ;
}
if ($authenticated) {
    $bind = @ldap_bind ($ldap, $admindn, $adminpw); 
} else 
    $bind = @ldap_bind ($ldap) ;


switch (readKey('action')) {
    case "userAddForm":
        userAddForm ($authenticated) ;
        break ;
    case "groupAddForm":
        ?>
<form method="post" name="add">
    <?php echo _("Enter groupname:") ; ?><BR>
    <input type=text name="cn"><BR>
    <?php echo _("Enter group description:") ; ?><BR>
    <input type=text name="description" size=50 ><BR>
    <BR>
<?php
    if ($authenticated) {
        $action ='\'addGroup&cn=\' + cn.value '; 
        $action .= ' + \'&description=\' + description.value' ;
    } else {
        $action = '\'loginForm\'' ; 
    }
?>
    <input type=button name=Remove value=Save
            onClick="Action(<?php echo $action ?>,'main')">
                <br>
    <input type=reset name=reset value=Reset> 
</form>
        <?php
        break ;
    case "groupSearch":
        $searchFor=readKey('Name') ;
        if ($searchFor <> "") showResult ($ldap, 'Group', $searchFor); 
        break ;
    case "groupSearchForm":
        ?>
<form method="post" name="search">
    Enter group to search for:<BR>
    <input type=text name="searchFor" size=50 
       onkeyup="Action ('groupSearch&Name=' + searchFor.value , 'Result');">
</form>
<div id="Result"></div>
        <?php
        break ;
    case "userSearch":
        $searchFor=readKey('Name') ;
        if ($searchFor <> "") showResult ($ldap, 'User', $searchFor); 
        break ;
    case "userSearchForm":
        ?>
<form method="post" name="search">
<?php echo _("Enter name to search for:") ; ?><BR>
<input type=text name="searchFor" size=50 
       onkeyup="Action ('userSearch&Name=' + searchFor.value , 'Result');">
</form>
<div id="Result"></div>
        <?php
        break ;
    case "showUser":
        showUser ($ldap, $authenticated, readKey('text')); 
        break ;
    case "userDelGroup":
        $uid = readKey('uid') ;
        userDelGroup ($ldap, $uid, readKey('gid')); 
        showUserGroups ($ldap, $authenticated, $uid);
        break ;
    case "userAddGroup":
        $uid = readKey('uid') ;
        userAddGroup ($ldap, $uid, readKey('gid')); 
        showUserGroups ($ldap, $authenticated, $uid);
        break ;
    case "changeUser":
        changeUser ($ldap, readKey('uid'), readKey('cn')); 
        break ;
    case "changeGroup":
        changeGroup ($ldap, readKey('gid'), readKey('cn'), readKey('description')); 
        break ;
    case "showGroup":
        showGroup ($ldap,readKey('text')); 
        break ;
    case "addUser":
	$cn = readKey('cn') ;
	$template = readKey('template') ;
	$username = readKey ('username'); 
	addUser ($ldap, $cn, $template, $username); 
        break ; 
    case "addGroup":
	addGroup ($ldap, readKey('cn'), readKey('description')); 
        break ; 
    case "getUsername":
        $cn=readKey('cn'); 
        if ($cn == "") {
            $username= "" ;
        } else
            $username = get_username ($ldap, $cn) ;
        echo '<input type=text name=username maxlength=8 value="' . $username . '">' ;
        break ; 
    case "newPassSet":
	$filter="(&(objectClass=posixAccount)(uid=" . readKey('uid') . "))";
	$want = array ('uid', 'cn') ; 
	$result= ldap_search ($ldap, $base, $filter, $want);
	$entries = ldap_get_entries ($ldap, $result);
	$newpw = pwgen (); 
	$cryptpw = cryptgen ($newpw); 
	$sambahash = ntlmgen ($newpw) ;
	$info = array ();
	$info["userPassword"][] = $cryptpw ;
	$info["sambaLMPassword"][] = substr ($sambahash, 0,32) ;
	$info["sambaNTPassword"][] = substr ($sambahash, 32) ;
	$result = ldap_modify ($ldap,$entries[0]["dn"],$info) ;
	printf(_("Changed password for %s to %s ."),$entries[0]['uid'][0],$entries[0]['cn'][0] );
        showUser ($ldap, $authenticated, $entries[0]['uid'][0]); 
	break ;
    case "newPassAsk":
        if ($authenticated) {
        echo _("Are you sure you want to set a new password ?") ;
?>
        <BR>
        <input type=button name=Yes value=Yes onClick="Action('newPassSet&uid=<?php echo readKey('uid') ; ?>', 'main');">
<?php
        break ; 
        }
    case "login":
        $adminUser=readKey('admindn') ;
        $filter = '(|(&(objectClass=posixAccount)(uid=' . $adminUser . '))(&(objectClass=simpleSecurityObject)(cn=' . $adminUser . ')))' ; 
        $want = array () ; 
        $result = ldap_search($ldap, $base, $filter, $want);
        $entries = ldap_get_entries ($ldap, $result); 
        $admindn = $entries[0]['dn'] ; 
        $adminpw=readKey('adminpw') ;
	$bind = @ldap_bind ($ldap, $admindn, $adminpw); 
	if ($bind) {
	    $key = $_SESSION['key'] ;
	    $xorstring= xorstring ($key, $adminpw); 
	    setcookie ('Authenticated', 'True') ;
	    setcookie ('admindn', $admindn) ;
	    setcookie ('xorstring', $xorstring) ;
	    break ; 
	}
    case "loginForm":
        ?>
<H2><?php echo _("You need to login before changing/adding anything") ; ?></H2>
<form name=askauth>
     <?php echo _("Login name:") ; ?><BR>
     <input type=text name=admindn><BR>
     <?php echo _("Login password:") ; ?><BR>
     <input type=password name=adminpw><BR>
     <input type=button name=login value=Login 
            onclick="Action('login&admindn=' + admindn.value + '&adminpw=' + adminpw.value, 'main');">
     <input type=reset name=reset value=Reset>
</form>
        <?php
        break ;
    default:
        echo "Function not implemented (yet). This is som debug info:" ;
        debug ($_POST);
        break ;
}
ldap_close ($ldap);

?>
